#!/usr/bin/env python
# -*-coding:utf-8 -*-
"""""" 
"""
@File    :   test_reorder.py
@Time    :   2022/06/25 23:07:13
@Author  :   Bart Ortiz 
@Version :   1.0
@Contact :   bortiz@ugr.es
@License :   CC-BY-SA or GPL3
@Desc    :   None
"""

# std import
import pytest
import pandas as pd
import numpy as np
import sys

sys.path.append(".")


# local import
from recorpy.reorder import ReorderCorr


@pytest.fixture(scope="module")
def global_data():
    """global_data fixture

    Returns:
        pandas.Dataframe: define matrix for calculations
    """

    np.random.seed(1)
    df = pd.DataFrame(np.random.rand(3, 3))
    return df


class Test_Utils:
    def setUp(self):
        # Aquí, opcionalmente, ejecuta lo que deberías ejecutar antes
        # de comenzar cada test.
        pass

    def test_ReorderCorr(self, global_data):
        """Test for ReorderCorr module

        Args:
            global_data ():
        """

        ordered_matrix = ReorderCorr(
            global_data,
            corr_threshold=0.8,
            corr_method="pearson",
            order="chain",
            manual_order=None,
        )

        assert ordered_matrix.columns.tolist() == [0, 1, 2]



#!/usr/bin/env python
# -*-coding:utf-8 -*-
"""""" 
"""
@File    :   __init__.py
@Time    :   2022/06/24 09:59:42
@Author  :   Bart Ortiz 
@Version :   0.1.6
@Contact :   bortiz@ugr.es
@License :   CC-BY-SA or GPL3
@Desc    :   Init file for the recorpy package
"""

from recorpy.reorder import ReorderCorr

__version__ = "0.1.7"



#!/usr/bin/env python
# -*-coding:utf-8 -*-
"""""" 
"""
@File    :   reorder.py
@Time    :   2022/06/24 10:41:13
@Author  :   Bart Ortiz 
@Version :   1.0
@Contact :   bortiz@ugr.es
@License :   CC-BY-SA or GPL3
@Desc    :   None
"""

import pandas as pd
import numpy as np
from sklearn.metrics.pairwise import cosine_similarity


def ReorderCorr(
    df, corr_threshold=0.8, corr_method="pearson", order="chain", manual_order=None
):

    """ReorderCorr reorders the columns of a dataframe based on its correlation matrix to analyze clusters better.
        It is based on METHODS OF REORDERING THE
        CORRELATION MATRIX TO FACILITATE VISUAL INSPECTION AND PRELIMINARY CLUSTER ANALYSIS
        (1973) by John Edward Hunter and de corReorder package by David W. Gerbing
        (Portland State University; gerbing@pdx.edu)

    Args:
        df (pandas.DataFrame): Dataframe with data
        corr_threshold (float, optional): Correlation threshold to apply. Defaults to 0.8.
        corr_method (str, optional): Correlation method to apply. Defaults to 'pearson'.
        order (str, optional): Order to apply (manual, hclust,chain ). Defaults to 'chain'.
        manual_order (list, optional): List of columns to apply. Defaults to None.

    Returns:
        (pandas.DataFrame): reordered dataframe

    Example:
        >>> df = pd.DataFrame(np.random.rand(3,3))
        >>> ReorderCorr(df)

    """
    df_corr = df.corr(method=corr_method)
    columns = df.columns
    if order == "manual" and manual_order is not None:
        reordered_df = df.reindex(columns=manual_order)
    elif order == "manual" and manual_order is None:
        raise ValueError("manual_order is None and order is manual")
    if order == "chain":
        similarity_matrix = cosine_similarity(df_corr)
        new_order = [columns[0]]
        for i in range(0, len(columns) - 1):
            sim_section = similarity_matrix[new_order[i]]
            next_index = np.argmax(sim_section)
            while next_index in new_order:
                sim_section[next_index] = -1
                next_index = np.argmax(sim_section)
            # print(next_index)
            new_order.append(columns[next_index])
        reordered_df = df.reindex(columns=new_order)

    return reordered_df



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['recorpy', 'recorpy.test']

package_data = \
{'': ['*']}

install_requires = \
['numpy>=1.23.0,<2.0.0', 'pandas>=1.4.3,<2.0.0', 'scikit-learn>=1.1.1,<2.0.0']

setup_kwargs = {
    'name': 'recorpy',
    'version': '0.1.7',
    'description': 'ReCorPy is a small package to reorder correlation matrices from dataframes for better visualizations',
    'long_description': '\n<p align="center">\n  <img src="https://raw.githubusercontent.com/thebooort/ReCorPy/main/assets/logo.png">\n</p>\n<h2 align="center">ReCorPy</h2>\n\n> A python\'s package for reordering/clustering correlation matrices\n\n[![DOI](https://zenodo.org/badge/506917975.svg)](https://zenodo.org/badge/latestdoi/506917975)\n[![Documentation Status](https://readthedocs.org/projects/recorpy/badge/?version=latest)](https://recorpy.readthedocs.io/en/latest/?badge=latest)\n[![PyPI Version][pypi-image]][pypi-url]\n[![Build Status][build-image]][build-url]\n[![Coverage Status](https://coveralls.io/repos/github/thebooort/ReCorPy/badge.svg?branch=main)](https://coveralls.io/github/thebooort/ReCorPy?branch=main)\n<a href="https://github.com/psf/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>\n\n`recorpy` reorder correlation matrixes to get better visual analysis. All it is made with the original dataframe. And the result\nis a new dataframe with columns reordered, to let you re-use it wherever you want.\n\nInput parameters:\n\n-   _method_ - \n-   _model_ - , default: \n-   _cluster_ - , default: \n\n\n## Installation\n\n```sh\npip install recorpy\n```\n\n## Usage\n\n\n```python\n        >>> df = pd.DataFrame(np.random.rand(3,3))\n        >>> ReorderCorr(df)\n```\n\n## Development setup\n\n```sh\n$ python3 -m venv env\n$ . env/bin/activate\n$ make deps\n$ tox\n```\n\n## Contributing\n\nPull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.\n\nMake sure to add or update tests as appropriate.\n\nUse [Black](https://black.readthedocs.io/en/stable/) for code formatting and [Conventional Commits](https://www.conventionalcommits.org/en/v1.0.0-beta.4/) for commit messages.\n\n## [Changelog](CHANGELOG.md)\n\n## License\n\n[GPL](https://choosealicense.com/licenses/gpl/)\n\n<!-- Badges -->\n\n[pypi-image]: https://img.shields.io/pypi/v/recorpy\n[pypi-url]: https://pypi.org/project/recorpy/\n[build-image]: https://github.com/thebooort/recorpy/actions/workflows/python-app.yml/badge.svg\n[build-url]: https://github.com/thebooort/recorpy/actions/workflows/python-app.yml\n\n',
    'author': 'thebooort',
    'author_email': '18428931+thebooort@users.noreply.github.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/thebooort/ReCorPy',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
